Index: public/web/WebView.h |
diff --git a/public/web/WebView.h b/public/web/WebView.h |
index 3fffa2809143a003d66428a4eed8759de3e25bdf..c2653e725fdb020d4bcfb5d9d58ce9faf58a6542 100644 |
--- a/public/web/WebView.h |
+++ b/public/web/WebView.h |
@@ -180,9 +180,12 @@ public: |
// Focus the first (last if reverse is true) focusable node. |
virtual void setInitialFocus(bool reverse) = 0; |
// Clears the focused node (and selection if a text field is focused) |
// to ensure that a text field on the page is not eating keystrokes we |
// send it. |
+ virtual void clearFocusedElement() = 0; |
+ |
+ // Deprecated API. Will be removed soon.. |
virtual void clearFocusedNode() = 0; |
// Scrolls the node currently in focus into view. |
@@ -180,9 +180,12 @@ public: |
// Focus the first (last if reverse is true) focusable node. |
virtual void setInitialFocus(bool reverse) = 0; |
- // Clears the focused node (and selection if a text field is focused) |
+ // Clears the focused element (and selection if a text field is focused) |
// to ensure that a text field on the page is not eating keystrokes we |
// send it. |